summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/interfaces/designerinterface.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/interfaces/designerinterface.h')
-rw-r--r--kdevdesigner/interfaces/designerinterface.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/kdevdesigner/interfaces/designerinterface.h b/kdevdesigner/interfaces/designerinterface.h
index 6fbefe53..d7f0667b 100644
--- a/kdevdesigner/interfaces/designerinterface.h
+++ b/kdevdesigner/interfaces/designerinterface.h
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000-2001 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -40,7 +40,7 @@
//
//
-#include <private/qcom_p.h>
+#include <private/tqcom_p.h>
#include <tqptrlist.h>
#include <tqstring.h>
#include <tqmap.h>
@@ -67,14 +67,14 @@ class TQSqlDatabase;
// {0e661da-f45c-4830-af47-03ec53eb1633}
#ifndef IID_Designer
-#define IID_Designer QUuid( 0xa0e661da, 0xf45c, 0x4830, 0xaf, 0x47, 0x3, 0xec, 0x53, 0xeb, 0x16, 0x33 )
+#define IID_Designer TQUuid( 0xa0e661da, 0xf45c, 0x4830, 0xaf, 0x47, 0x3, 0xec, 0x53, 0xeb, 0x16, 0x33 )
#endif
-/*! These are the interfaces implemented by the Qt Designer which should
- be used by plugins to access and use functionality of the Qt Designer.
+/*! These are the interfaces implemented by the TQt Designer which should
+ be used by plugins to access and use functionality of the TQt Designer.
*/
-struct DesignerInterface : public QUnknownInterface
+struct DesignerInterface : public TQUnknownInterface
{
virtual DesignerProject *currentProject() const = 0;
virtual DesignerFormWindow *currentForm() const = 0;
@@ -180,7 +180,7 @@ struct DesignerFormWindow
virtual bool isModified() const = 0;
virtual void insertWidget( TQWidget * ) = 0;
virtual void removeWidget( TQWidget * ) = 0;
- virtual TQWidget *create( const char *className, TQWidget *parent, const char *name ) = 0;
+ virtual TQWidget *create( const char *className, TQWidget *tqparent, const char *name ) = 0;
virtual TQWidgetList widgets() const = 0;
virtual void undo() = 0;
virtual void redo() = 0;
@@ -190,14 +190,14 @@ struct DesignerFormWindow
virtual void adjustSize() = 0;
virtual void editConnections() = 0;
virtual void checkAccels() = 0;
- virtual void layoutH() = 0;
- virtual void layoutV() = 0;
- virtual void layoutHSplit() = 0;
- virtual void layoutVSplit() = 0;
- virtual void layoutG() = 0;
- virtual void layoutHContainer( TQWidget* w ) = 0;
- virtual void layoutVContainer( TQWidget* w ) = 0;
- virtual void layoutGContainer( TQWidget* w ) = 0;
+ virtual void tqlayoutH() = 0;
+ virtual void tqlayoutV() = 0;
+ virtual void tqlayoutHSplit() = 0;
+ virtual void tqlayoutVSplit() = 0;
+ virtual void tqlayoutG() = 0;
+ virtual void tqlayoutHContainer( TQWidget* w ) = 0;
+ virtual void tqlayoutVContainer( TQWidget* w ) = 0;
+ virtual void tqlayoutGContainer( TQWidget* w ) = 0;
virtual void breakLayout() = 0;
virtual void selectWidget( TQWidget * w ) = 0;
virtual void selectAll() = 0;
@@ -209,7 +209,7 @@ struct DesignerFormWindow
virtual void setCurrentWidget( TQWidget * ) = 0;
virtual TQPtrList<TQAction> actionList() const = 0;
virtual TQAction *createAction( const TQString& text, const TQIconSet& icon, const TQString& menuText, int accel,
- TQObject* parent, const char* name = 0, bool toggle = FALSE ) = 0;
+ TQObject* tqparent, const char* name = 0, bool toggle = FALSE ) = 0;
virtual void addAction( TQAction * ) = 0;
virtual void removeAction( TQAction * ) = 0;
virtual void preview() const = 0;
@@ -1,15 +1,15 @@
** Copyright (C) 2000-2001 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the